# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # OFFICE
    def v1_office_office_list(self, profile,  filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_office_office_retrieve(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_office_office_create(self, profile,  post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_office_update(self, profile,  pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_office_enable(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_office_disable(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_office_destroy(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:office-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # AREA -

    def v1_office_area_list(self, profile,  filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_office_area_retrieve(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_office_area_create(self, profile,  post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_area_update(self, profile,  pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_area_enable(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_area_disable(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_office_area_destroy(self, profile,  pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-office:area-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
