# -*- coding: utf-8 -*-

import django
from django.db import models
from django.utils.translation import gettext_lazy as _

if django.VERSION < (3, 1):
    from django.contrib.postgres.fields import JSONField
else:
    from django.db.models import JSONField

from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel


class Office(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        unique=True,
        verbose_name=_("code")
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_("office")
    )
    description = models.TextField(
        blank=True,
        max_length=255,
        verbose_name=_("description")
    )
    phone = models.CharField(
        max_length=20,
        verbose_name=_("phone"),
    )
    fax = models.CharField(
        max_length=20,
        verbose_name=_("fax"),
    )
    email = models.EmailField(
        max_length=100,
        blank=True, null=True,
        verbose_name=_("email"),
    )

    class Meta:
        verbose_name = _('office')
        verbose_name_plural = _('office')
        ordering = ('ordering',)
        permissions = (
            ("list_office", "Can list office"),
            ("detail_office", "Can detail office"),
            ("enable_office", "Can enable office"),
            ("disable_office", "Can disable office"),
        )

    def __str__(self):
        return self.name


class Area(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        primary_key=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    default_info = JSONField(
        null=True, blank=True,
        verbose_name=_('default info'),
        help_text=_("put here default extra info about this area"),
    )

    class Meta:
        verbose_name = _('area')
        verbose_name_plural = _('areas')
        ordering = ('ordering',)
        permissions = (
            ("list_area", "Can list area"),
            ("detail_area", "Can detail area"),
            ("enable_area", "Can enable area"),
            ("disable_area", "Can disable area"),
        )

    def __str__(self):
        return self.name
